==> diablo-1.08.tgz: diablo/lib/protos.h <==
Prototype char *NewsHome;
Prototype char *SpoolHome;
Prototype volatile int DebugOpt;
Prototype void FreeNodeList(Node **pnode);
Prototype void FreeNode(Node *node);
Prototype Node *MakeNode(const char *str, int val);
Prototype Node *MakeNode2(const char *str1, const char *str2, int val);
Prototype int xopen(int modes, int perms, const char *ctl, ...);
Prototype FILE *xfopen(const char *modes, const char *ctl, ...);
Prototype int xfprintf(FILE *fo, const char *ctl, ...);
Prototype void dprintf(const char *ctl, ...);
Prototype void vdprintf(const char *ctl, va_list va);
Prototype FILE *fcdopen(const char *path, const char *modes);
Prototype int cdopen(const char *path, int modes, int perms);
Prototype const char *cdcache(const char *path);
Prototype char *bgets(Buffer **pb, int fd);
Prototype void bclose(Buffer **pb);
Prototype int WildCmp(const char *w, const char *s);
Prototype int WildCaseCmp(const char *w, const char *s);
Prototype void HistoryOpen(const char *fileName, int fastMode);
Prototype int  HistoryClose(void);
Prototype int HistoryLookup(const char *msgid, char **pfi, long *rsize, int *pmart);
Prototype int HistoryLookupByHash(hash_t hv, History *h);
Prototype int HistoryAdd(const char *msgid, History *h);
Prototype hash_t hhash(const char *msgid);
Prototype char *MsgId(char *s);
Prototype int GetExpire(const char *msgid, History *h, const char *nglist, int size);
Prototype void LoadExpireCtl(History *h, int force);
Prototype int FeedAdd(const char *msgid, History *h, const char *nglist, const char *npath, int size);
Prototype void FeedFlush(void);
Prototype void LoadNewsFeed(History *h, int force);
Prototype void TouchNewsFeed(void);
Prototype int IsFiltered(const char *hlabel, const char *nglist);
Prototype FILE *FeedFo;
Prototype time_t parsedate(char *buf);
Prototype void rsignal(int sigNo, void (*func)(int sigNo));
Prototype int xflock(int fd, int flags);
Prototype int hflock(int fd, int offset, int flags);
Prototype void *pagealloc(int *psize);
Prototype void pagefree(void *p);
Prototype void ArticleFileName(char *path, History *h, int absolute);
Prototype void *xmap(void *addr, size_t len, int prot, int flags, int fd, off_t offset);
Prototype void xunmap(void *addr, size_t len);

==> diablo-1.10.tgz: diablo/lib/protos.h <==
Prototype char *NewsHome;
Prototype char *SpoolHome;
Prototype volatile int DebugOpt;
Prototype void FreeNodeList(Node **pnode);
Prototype void FreeNode(Node *node);
Prototype Node *MakeNode(const char *str, int val);
Prototype Node *MakeNode2(const char *str1, const char *str2, int val);
Prototype int xopen(int modes, int perms, const char *ctl, ...);
Prototype FILE *xfopen(const char *modes, const char *ctl, ...);
Prototype int xfprintf(FILE *fo, const char *ctl, ...);
Prototype void dprintf(const char *ctl, ...);
Prototype void vdprintf(const char *ctl, va_list va);
Prototype FILE *fcdopen(const char *path, const char *modes);
Prototype int cdopen(const char *path, int modes, int perms);
Prototype const char *cdcache(const char *path);
Prototype Buffer *bopen(int fd);
Prototype void bclose(Buffer *b, int closeFd);
Prototype char *bgets(Buffer *b, int *pbytes);
Prototype void bwrite(Buffer *b, const void *data, int bytes);
Prototype void bflush(Buffer *b);
Prototype int  berror(Buffer *b);
Prototype off_t btell(Buffer *b);
Prototype int bunget(Buffer *b, int n);
Prototype int WildCmp(const char *w, const char *s);
Prototype int WildCaseCmp(const char *w, const char *s);
Prototype void HistoryOpen(const char *fileName, int fastMode);
Prototype int  HistoryClose(void);
Prototype int HistoryLookup(const char *msgid, char **pfi, long *rsize, int *pmart);
Prototype int HistoryLookupByHash(hash_t hv, History *h);
Prototype int HistoryAdd(const char *msgid, History *h);
Prototype hash_t hhash(const char *msgid);
Prototype void bhash(hash_t *h, const char *p, int len);
Prototype char *MsgId(char *s);
Prototype int GetExpire(const char *msgid, History *h, const char *nglist, int size);
Prototype void LoadExpireCtl(History *h, int force);
Prototype int FeedAdd(const char *msgid, History *h, const char *nglist, const char *npath, int size);
Prototype void FeedFlush(void);
Prototype void LoadNewsFeed(History *h, int force);
Prototype void TouchNewsFeed(void);
Prototype int IsFiltered(const char *hlabel, const char *nglist);
Prototype int FeedQuerySpam(const char *hlabel, const char *hostInfo);
Prototype FILE *FeedFo;
Prototype time_t parsedate(char *buf);
Prototype void rsignal(int sigNo, void (*func)(int sigNo));
Prototype int xflock(int fd, int flags);
Prototype int hflock(int fd, int offset, int flags);
Prototype void *pagealloc(int *psize);
Prototype void pagefree(void *p);
Prototype int ZoneFd;		/* only necessary for USE_FALL_MMAP */
Prototype void ArticleFileName(char *path, History *h, int absolute);
Prototype void strlcpy(char *d, const char *s, int ssize, int dsize);
Prototype void *xmap(void *addr, size_t len, int prot, int flags, int fd, off_t offset);
Prototype void xunmap(void *addr, size_t len);
Prototype int PreCommit(const char *msgid);
Prototype int SetPreCommitExpire(int pcex);
Prototype void SetFilterTrip(int n);
Prototype int SpamFilter(hash_t mhv, const char *nntpPostingHost, hash_t *bhv, int *phow);
Prototype void DumpSpamFilterCache(void);
